@@ -41,6 +41,10 @@ public:
     QList<ComicProviderInfo> loadProviders();
 
     void setMaxComicLimit(int maxComicLimit);
+    void setIsCheckingForUpdates(bool isCheckingForUpdates);
+
+    bool isCheckingForUpdates();
+
     bool requestSource(const QString &identifier);
 
 Q_SIGNALS:
@@ -55,6 +59,7 @@ private:
 
 private:
     bool mEmptySuffix;
+    bool mIsCheckingForUpdates;
     QString mIdentifierError;
     QHash<QString, ComicProvider *> m_jobs;
     QSet<QString> mProviders;
